==> binnie-mods-1.11.2-2.1.0.20-sources.jar: binnie/genetics/item/GeneticsItems.java <==
package binnie.genetics.item;

import java.util.List;

import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;

import binnie.core.item.IItemMiscProvider;
import binnie.genetics.Genetics;

public enum GeneticsItems implements IItemMiscProvider {
	LaboratoryCasing("Reinforced Casing", "casing_iron"),
	DNADye("DNA Dye", "dna_dye"),
	FluorescentDye("Fluorescent Dye", "dye_fluor"),
	Enzyme("Enzyme", "enzyme"),
	GrowthMedium("Growth Medium", "growth_medium"),
	EmptySequencer("Blank Sequence", "sequencer_empty"),
	EMPTY_SERUM("Empty Serum Vial", "serum_empty"),
	EMPTY_GENOME("Empty Serum Array", "genome_empty"),
	IntegratedCircuit("Integrated Circuit Board", "integrated_circuit"),
	IntegratedCPU("Integrated CPU", "integrated_cpu"),
	IntegratedCasing("Integrated Casing", "casing_circuit");

	String name;
	String modelPath;

	GeneticsItems(final String name, final String modelPath) {
		this.name = name;
		this.modelPath = modelPath;
	}

	@Override
	public String getModelPath() {
		return modelPath;
	}

	@Override
	public void addInformation(final List<String> tooltip) {
	}

	@Override
	public String getDisplayName(final ItemStack stack) {
		return this.name;
	}

	@Override
	public ItemStack get(final int size) {
		return new ItemStack(Genetics.items().getItemGenetics(), size, this.ordinal());
	}

	public ItemStack get(Item itemGenetics, final int size) {
		return new ItemStack(itemGenetics, size, this.ordinal());
	}

	@Override
	public boolean isActive() {
		return true;
	}
}

==> binnie-mods-1.12.1-2.3.0.75-sources.jar: binnie/genetics/item/GeneticsItems.java <==
package binnie.genetics.item;

import java.util.List;

import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;

import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

import binnie.core.item.IItemMiscProvider;
import binnie.genetics.Genetics;

public enum GeneticsItems implements IItemMiscProvider {
	LaboratoryCasing("Reinforced Casing", "casing_iron"),
	DNADye("DNA Dye", "dna_dye"),
	FluorescentDye("Fluorescent Dye", "dye_fluor"),
	Enzyme("Enzyme", "enzyme"),
	GrowthMedium("Growth Medium", "growth_medium"),
	EmptySequencer("Blank Sequence", "sequencer_empty"),
	EMPTY_SERUM("Empty Serum Vial", "serum_empty"),
	EMPTY_GENOME("Empty Serum Array", "genome_empty"),
	IntegratedCircuit("Integrated Circuit Board", "integrated_circuit"),
	IntegratedCPU("Integrated CPU", "integrated_cpu"),
	IntegratedCasing("Integrated Casing", "casing_circuit");

	private final String name;
	private final String modelPath;

	GeneticsItems(final String name, final String modelPath) {
		this.name = name;
		this.modelPath = modelPath;
	}

	@Override
	public String getModelPath() {
		return modelPath;
	}

	@Override
	@SideOnly(Side.CLIENT)
	public void addInformation(final List<String> tooltip) {
	}

	@Override
	public String getDisplayName(final ItemStack stack) {
		return this.name;
	}

	@Override
	public ItemStack get(final int size) {
		return new ItemStack(Genetics.items().getItemGenetics(), size, this.ordinal());
	}

	public ItemStack get(Item itemGenetics, final int size) {
		return new ItemStack(itemGenetics, size, this.ordinal());
	}

	@Override
	public boolean isActive() {
		return true;
	}
}
